@@ -158,7 +158,6 @@ class PanStation(QLabel):
         self.state = False
         self.setFont(QFont ( "Nokia Sans",_RAYON*2  ))
         self.setAlignment(Qt.AlignCenter)
-        self.setStyleSheet("background-color: qlineargradient(x1:-0.5, y1:-0.5, x2:1, y2:1, stop:0 white,  stop:1 palette(highlight)) ; color: palette(highlighted-text) ;border:3px solid gray; border-top-style: none; border-right-style: none")
 
         self.animX = QPropertyAnimation (self, "pos")
         self.animX.setDuration(_TEMPS_ANIM/5)
@@ -177,14 +176,14 @@ class PanStation(QLabel):
             self.resize(size.width()+_RAYON*2,70)
             self.setText(text)
             self.animX.setKeyValueAt(0, QPoint(900,y))
-            self.animX.setKeyValueAt(1, QPoint(w-min(290,self.width()),y) )
+            self.animX.setKeyValueAt(1, QPoint(w-min(220,self.width()),y) )
             self.emit(SIGNAL("showing(int)"),-1)
             self.state = True
             self.animX.start()
 
         elif self.text() != '':
             self.setText(text)
-            self.animX.setKeyValueAt(0, QPoint(w-min(290,self.width()),y))
+            self.animX.setKeyValueAt(0, QPoint(w-min(220,self.width()),y))
             self.animX.setKeyValueAt(1, QPoint(900,y))
             self.emit(SIGNAL("showing(int)"),1)
             self.state = False
@@ -286,7 +285,15 @@ class GpsButton(QLabel):
         
         self.setAlignment(Qt.AlignCenter)
         self.setPixmap (  self.pixNo)
+        self.setScaledContents( True )
+        self.setMargin(16)
         self.state = False
+
+        self.animMargin = QPropertyAnimation (self, "margin")
+        self.animMargin.setDuration(_TEMPS_ANIM)
+        self.animMargin.setEasingCurve(QEasingCurve.OutElastic)
+        self.animMargin.setKeyValueAt(0, 8)
+        self.animMargin.setKeyValueAt(1, 16)
         
         
         self.click = QTimer(self)
@@ -300,6 +307,8 @@ class GpsButton(QLabel):
     def mouseDoubleClickEvent(self, event):
         self.changeState()
         QLabel.mouseDoubleClickEvent (self, event)
+
+
         
     def mouseReleaseEvent(self,event):
         self.click.stop()
@@ -309,11 +318,14 @@ class GpsButton(QLabel):
     def mousePressEvent(self,event):
         self.click.stop()
         self.click.start(_TEMPS_CLICK)
+        self.animMargin.start()
         QLabel.mousePressEvent (self, event)
         
     def setPix(self,t):
         if t == 'On':
             self.setPixmap (  self.pixOn)
+            self.animMargin.setKeyValueAt(0, 0)
+            self.animMargin.setKeyValueAt(1, 8)
         elif t == 'Good':
             self.setPixmap (  self.pixGood)
         elif t == 'Off':
@@ -370,7 +382,7 @@ class Gps(QGraphicsEllipseItem):
    
     def deselec(self):
         gradient = QRadialGradient(0,0, _RAYON*1.5)
-        gradient.setColorAt(1, Qt.black)
+        gradient.setColorAt(1, Qt.red)
         gradient.setColorAt(0, Qt.red)
         self.setPen(QPen(gradient, _RAYON))
         
@@ -385,6 +397,7 @@ class diagSearch(QWidget):
         self.hide()
         self.setGeometry(50,50,parent.width()-100,65)
         self.graph = graph
+        self.changed = True
         
       
         self.Line = QLineEdit(self)
@@ -413,28 +426,37 @@ class diagSearch(QWidget):
 
         self.Line.setFocus ( Qt.MouseFocusReason)
         self.Line.returnPressed.connect(self.cherche)
+        self.Line.textChanged.connect(self.changing)
         self.Search.clicked.connect(self.cherche)
         QObject.connect(self.parent(), SIGNAL("pressed()"), self.close)
         
+    def changing(self):
+        self.changed = True
+        
     def cherche(self):
-        result = []
-        self.List.clear()
-        for element in self.graph:
-            if str(self.Line.text().toLower()) in element.lower():
-                result += [element]
-        if result == []:
-            QMaemo5InformationBox.information( self, 'La recherche n\'a donn\xe9 aucun r\xe9sultat.' )
-        elif len(element) == 1 or str(self.Line.text()) in result:
-            self.emit(SIGNAL("selected(QString)"),self.Line.text())
+        if self.changed:
+            result = []
             self.List.clear()
-            self.List.hide()
-            self.close()
+            for element in self.graph:
+                if str(self.Line.text().toLower()) in element.lower():
+                    result += [element]
+            if result == []:
+                QMaemo5InformationBox.information( self, 'La recherche n\'a donn\xe9 aucun r\xe9sultat.' )
+            elif len(element) == 1 or str(self.Line.text()) in result:
+                self.emit(SIGNAL("selected(QString)"),self.Line.text())
+                self.List.clear()
+                self.List.hide()
+                self.close()
+            else:
+                for stop in result:
+                    self.List.addItem(stop)
+                self.resize(self.width(),min(self.height()+74*len(result),self.parent().height()-100))
+                self.List.resize(self.width()-64,min(74*len(result),self.height()-64))
+                self.List.show()
+                self.changed = False
         else:
-            for stop in result:
-                self.List.addItem(stop)
-            self.resize(self.width(),min(self.height()+74*len(result),self.parent().height()-100))
-            self.List.resize(self.width()-64,min(74*len(result),self.height()-64))
-            self.List.show()
+            self.selec(self.List.currentItem())
+
         
     def selec(self,it):
         self.emit(SIGNAL("selected(QString)"),it.text())
@@ -620,6 +642,10 @@ class diagLigne(QWidget):
         self.parent().scene().addItem(self.fond)
         QWidget.showEvent (self, event)
 
+    def mousePressEvent(self,event):
+        self.close()
+        QWidget.mousePressEvent (self, event)
+
     def closeEvent(self,event):
         selec = []
         for idx in range(25):
@@ -708,7 +734,7 @@ class diagAide(QWidget):
         self.Titre.setFont(QFont('Nokia Sans',48))
         self.Titre.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Fixed))
         self.Text = QTextEdit('''<p align="center"><span style=" font-size:32pt; font-weight:600;">Carte</span></p>
-<p><b>Selection d'une station:</b></p>
+<p><b>S\xe9lection d'une station:</b></p>
 <p>Double-clique sur la station.</p>
 <p><br /><b>D\xe9placement:</b></p>
 <p>Clique et gliss\xe9.<br /></p>
@@ -719,13 +745,13 @@ class diagAide(QWidget):
 <p></p>
 <p><br /><b>GPS:</b></p>
 <p><img src="/usr/share/icons/hicolor/32x32/hildon/camera_gps_location.png" width="32" height="32"/> : Double-clique pour activer la localisation.</p>
-<p><img src="/usr/share/icons/hicolor/48x48/hildon/location_applet_track_start.png" width="32" height="32"/> : GPS activ\xe9.</p>
-<p><img src="/usr/share/icons/hicolor/48x48/hildon/location_applet_track_stop_ani.png" width="32" height="32"/> : Localisation pr\xe9cise.</p>
+<p><img src="/usr/share/icons/hicolor/48x48/hildon/location_applet_track_start.png" width="32" height="32"/> : GPS activ\xe9. Double-clique pour d\xe9sactiver la localisation.</p>
+<p><img src="/usr/share/icons/hicolor/48x48/hildon/location_applet_track_stop_ani.png" width="32" height="32"/> : Localisation pr\xe9cise. Double-clique pour d\xe9sactiver la localisation.</p>
 <p><img src="/usr/share/icons/hicolor/48x48/hildon/sketch_circle.png" width="32" height="32"/> : GPS d\xe9sactiv\xe9 mais position enregistr\xe9e.</p>
 <p>Clique long (1s) pour centrer la carte la position GPS.</p>
 <p></p>
 <p><br /><b>Panneaux:</b></p>
-<p>Clique pour cacher et d\xe9selectionner la station.</p>
+<p><img src="img_panneaux.png"/> : Clique pour cacher et d\xe9s\xe9lectionner la station.</p>
 <p></p>
 <p><img src="/usr/share/icons/hicolor/48x48/hildon/statusarea_sharing_pending.png" width="32" height="32"/> : Calculer l'itin\xe9raire.</p>
 <p><img src="/usr/share/icons/hicolor/48x48/hildon/statusarea_sharing.png" width="32" height="32"/> : Calcul en cours.</p>
@@ -733,11 +759,12 @@ class diagAide(QWidget):
 <p><br /></p>
 <p align="center"><span style=" font-size:32pt; font-weight:600;">Menu:</span></p>
 <p><br /><b>Recherche:</b></p>
-<p>Selection: Double clique.</p>
+<p>S\xe9lection: Double clique.</p>
 <p>Sortir: Clique ailleurs.</p>
 <p></p>
-<p><br /><b>Selection des lignes:</b></p>
-<p>Selection/D\xe9selection : Clique</p>
+<p><br /><b>S\xe9lection des lignes:</b></p>
+<p>S\xe9lection/D\xe9s\xe9lection : Clique</p>
+<p>Les noms des stations sont affich\xe9 si maximum <b>quatre</b> lignes sont s\xe9lectionn\xe9es.</p>
 <p>Sortir/Valider: Clique ailleurs.</p>
 <p></p>
 <p><br /><b>Aide:</b></p>
@@ -748,6 +775,7 @@ class diagAide(QWidget):
 <p><br /></p>''',self.scroll)
         self.Text.setFont(QFont('Nokia Sans',18))
         self.Text.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed))
+        self.Text.setReadOnly ( True )
 #        self.Text.setWordWrap(True)
         
         self.Layout.addWidget(self.Titre)
@@ -759,7 +787,7 @@ class diagAide(QWidget):
     def rotate(self):
         if self.parent().width() < self.parent().height():
             self.setGeometry(10,50,460,600)
-            self.Text.resize(self.width()-40,2100)        
+            self.Text.resize(self.width()-40,2250)        
         else:
             self.setGeometry(100,60,600,340)
             self.Text.resize(self.width()-40,2000)
@@ -768,6 +796,7 @@ class diagAide(QWidget):
     def showEvent(self,event):
         self.parent().scene().addItem(self.fond)
         QWidget.showEvent (self, event)
+
         
     def closeEvent(self,event):
         QObject.disconnect(self.parent(), SIGNAL("pressed()"), self.close)
