@@ -773,13 +773,13 @@ class Ui_MainWindow(QMainWindow):
 
 
         self.panArrivee = classes.PanStation(self.view)
-        self.panArrivee.setGeometry(900,self.view.height()-126,250,180)
+        self.panArrivee.setGeometry(900,app.desktop().screenGeometry().height()-126,250,180)
         QObject.connect(self.panArrivee, SIGNAL("released(QString)"), self.deselec)
         self.panArrivee.setStyleSheet("background-color: qlineargradient(x1:3, y1:2, x2:0, y2:0, stop:0 palette(light),  stop:1 palette(highlight)) ; color: palette(highlighted-text) ;border-left:3px solid palette(highlight); border-top:3px solid palette(highlight);")
         self.panArrivee.show()
 
         self.panAction = classes.PanAction(self.view)
-        self.panAction.setGeometry(900,self.view.height()/2-56-20,80,80)
+        self.panAction.setGeometry(900,app.desktop().screenGeometry().height()/2-56-20,80,80)
         QObject.connect(self.panAction, SIGNAL("colorise"), self.colorise)
         QObject.connect(self.panAction, SIGNAL("play"), self.play)
         self.panAction.show()
@@ -798,7 +798,7 @@ class Ui_MainWindow(QMainWindow):
         QObject.connect(self.gpsButton, SIGNAL("gpsOn"), self.addGPS)
         QObject.connect(self.gpsButton, SIGNAL("gpsOff"), self.closeSession)
         QObject.connect(self.gpsButton, SIGNAL("gpsCenter"), self.gpsCenter)
-        self.gpsButton.setGeometry(0,self.view.height()-64-56,64,64)
+        self.gpsButton.setGeometry(0,app.desktop().screenGeometry().height()-64-56,64,64)
         self.gpsButton.show()
 
 ######### Menu
@@ -824,7 +824,7 @@ class Ui_MainWindow(QMainWindow):
 
 #########
 
-        if self.view.width() < self.view.height():
+        if app.desktop().screenGeometry().width() < app.desktop().screenGeometry().height():
             self.view.centerOn(1900.,-500) 
         else:
             self.view.centerOn(1750.,-400)
